// SPDX-FileCopyrightText: 2024 Tobias Leupold <tl at stonemx dot de>
//
// SPDX-License-Identifier: GPL-3.0-or-later

#ifndef BOOKINGENGINE_H
#define BOOKINGENGINE_H

// Qt includes
#include <QObject>
#include <QString>

// Local classes
class TournamentSettings;

class BookingEngine : public QObject
{
    Q_OBJECT

public:
    static const int maxEscapedLength;

    struct QrData
    {
        bool isValid = false;
        QString name;
        QString tournament;
        QString checksum;
        QString error;
    };

    explicit BookingEngine(QObject *parent, TournamentSettings *tournamentSettings);
    void reload();
    void setTournamentName(const QString &name);
    const QString &tournamentName() const;
    void setSecurityKey(const QString &key);
    const QString &securityKey() const;
    void saveSettings();
    QString checksum(const QString &name, const QString &tournament = QString()) const;
    QByteArray serialize(const QString &name, const QString &checksum) const;
    QrData parse(const QString &data) const;
    void reset();
    QString escape(const QString &string) const;
    bool looksLikeBookingCode(const QString &string) const;
    bool containsBookingCodeHeader(const QString &string) const;

private: // Functions
    bool parseSettings(const QString &settings);
    QString unEscape(const QString &string) const;
    QByteArray encodeInt(int value) const;
    int decodeInt(const QString &value) const;
    QByteArray encodeChecksum(const QString &checksum) const;
    QString decodeChecksum(const QString &text) const;
    QString swapReplacementChars(const QString &text) const;

private: // Variables
    TournamentSettings *m_tournamentSettings;

    QString m_tournamentName;
    QString m_escapedTournamentName;
    QString m_securityKey;

};

#endif // BOOKINGENGINE_H
