// SPDX-FileCopyrightText: 2020-2023 Tobias Leupold <tl at stonemx dot de>
//
// SPDX-License-Identifier: GPL-3.0-or-later

#ifndef SCORESETTINGSPAGE_H
#define SCORESETTINGSPAGE_H

// Local includes
#include "shared/AbstractSettingsPage.h"
#include "shared/Tournament.h"

// Local classes

class TournamentSettings;

namespace TournamentTemplate
{
struct Settings;
}

// Qt classes
class QRadioButton;
class QCheckBox;
class QGroupBox;

class ScoreSettingsPage : public AbstractSettingsPage
{
    Q_OBJECT

public:
    explicit ScoreSettingsPage(const TournamentTemplate::Settings &tournamentTemplate,
                               TournamentSettings *tournamentSettings,
                               QWidget *parent = nullptr);
    void saveSettings() override;

public Q_SLOTS:
    void tournamentModeSelected(Tournament::Mode mode);

private Q_SLOTS:
    void noTableNumbersChanged(int state);

private: // Variables
    TournamentSettings *m_tournamentSettings;
    QRadioButton *m_scoreTypeHorizontal;
    QRadioButton *m_scoreTypeVertical;
    QGroupBox *m_autoSelectBox;
    QCheckBox *m_autoSelectPairs;
    QCheckBox *m_selectByLastRound;
    QCheckBox *m_noTableNumbers;

    bool m_lastAutoSelectPairsState;
    bool m_lastSelectByLastRoundState;

};

#endif // SCORESETTINGSPAGE_H
