// SPDX-FileCopyrightText: 2023-2024 Tobias Leupold <tl at stonemx dot de>
//
// SPDX-License-Identifier: GPL-3.0-or-later

#ifndef REGISTRATIONSMODEL_H
#define REGISTRATIONSMODEL_H

// Local includes

#include "shared/Draw.h"
#include "shared/Players.h"

#include "Database/Database.h"

// Qt includes
#include <QAbstractTableModel>
#include <QIcon>

// Local classes
class SharedObjects;
class StringTools;
class SearchEngine;
class TournamentSettings;
class MarkersModel;

class RegistrationsModel : public QAbstractTableModel
{
    Q_OBJECT

public:
    explicit RegistrationsModel(QObject *parent, SharedObjects *sharedObjects,
                                const MarkersModel *markersModel);
    int rowCount(const QModelIndex &index = QModelIndex()) const override;
    int columnCount(const QModelIndex & = QModelIndex()) const override;
    Qt::ItemFlags flags(const QModelIndex &index) const override;
    QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const override;
    QVariant headerData(int section, Qt::Orientation orientation,
                        int role = Qt::DisplayRole) const override;

    void clear();
    void refresh();
    const QHash<int, int> &markerCounts() const;
    int markerCount(int marker) const;
    const QVector<int> &assignedTables(int pair) const;
    const QVector<int> &incompleteTables() const;
    const QVector<int> &tableGaps() const;
    const Players::Data &data(int row) const;
    const Players::Data &data(const QString &name) const;
    const QVector<Players::Data> &playersData() const;
    bool hasExactMatch(const QString &name) const;
    bool hasCaseInsensitiveMatch(const QString &name) const;
    QString hasFuzzyMatch(const QString &text, bool phoneticSearch,
                          const QString &exclude = QString()) const;
    int rowForName(const QString &name) const;
    QModelIndex indexForName(const QString &name) const;
    bool assignmentPresent() const;
    int drawsCount() const;
    void updateSearchHidden(const QString &text, bool phoneticSearch);
    bool isSearchHidden(int row) const;
    bool isMarkerHidden(int row) const;
    const QString &searchTerm() const;
    const QVector<int> &numbers() const;
    const QString &nameForBookingChecksum(const QString &checksum) const;

private: // Variables
    const int m_columnCount;
    Database *m_db;
    StringTools *m_stringTools;
    SearchEngine *m_searchEngine;
    TournamentSettings *m_tournamentSettings;
    const MarkersModel *m_markersModel;
    const QIcon m_markerIcon;
    const QIcon m_drawIcon;
    const QIcon m_disqualifiedIcon;
    QString m_searchTerm;
    bool m_phoneticSearch = false;

    QVector<Players::Data> m_playersData;
    int m_rowCount = 0;
    QHash<int, QColor> m_markerColors;
    QHash<int, QString> m_markerNames;
    QHash<int, int> m_markerCounts;
    QVector<int> m_assignedPair1Tables;
    QVector<int> m_assignedPair2Tables;
    QVector<int> m_incompleteTables;
    QVector<int> m_tableGaps;
    QVector<bool> m_searchHidden;
    QVector<int> m_numbers;

};

#endif // REGISTRATIONSMODEL_H
