// SPDX-FileCopyrightText: 2024 Tobias Leupold <tl at stonemx dot de>
//
// SPDX-License-Identifier: GPL-3.0-or-later

// Local includes
#include "FontDialog.h"

// Qt includes
#include <QDebug>
#include <QFontDatabase>
#include <QListWidget>
#include <QVBoxLayout>
#include <QLabel>
#include <QDialogButtonBox>

// C++ includes
#include <utility>

FontDialog::FontDialog(QWidget *parent) : QDialog(parent)
{
    setWindowTitle(tr("Schriftart auswählen"));

    auto *layout = new QVBoxLayout(this);
    m_fonts = new QListWidget;
    layout->addWidget(m_fonts);

    QFontDatabase db;
    const auto families = db.families();
    for (const auto &family : families) {
        if (db.isPrivateFamily(family)) {
            continue;
        }
        m_fonts->addItem(family);
    }

    m_preview = new QLabel(tr("Beginn der nächsten Runde"));
    m_preview->setWordWrap(true);
    auto previewFont = m_preview->font();
    previewFont.setPointSize(35);
    m_preview->setFont(previewFont);
    layout->addWidget(m_preview);

    connect(m_fonts, &QListWidget::currentItemChanged, this, &FontDialog::updatePreview);

    auto *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel);
    layout->addWidget(buttonBox);
    connect(buttonBox, &QDialogButtonBox::accepted, this, &QDialog::accept);
    connect(buttonBox, &QDialogButtonBox::rejected, this, &QDialog::reject);
}

int FontDialog::execWithFont(const QFont &font)
{
    const auto items = m_fonts->findItems(font.family(), Qt::MatchExactly);
    if (items.count() > 0) {
        m_fonts->setCurrentItem(items.first());
    }

    return QDialog::exec();
}

void FontDialog::updatePreview(QListWidgetItem *item)
{
    m_selectedFont = item->text();
    auto previewFont = m_preview->font();
    previewFont.setFamily(m_selectedFont);
    m_preview->setFont(previewFont);
}

const QString &FontDialog::selectedFont() const
{
    return m_selectedFont;
}
